diff mbox series

[13/16] drm/i915/dpll: Rename intel_unreference_dpll_global_crtc

Message ID 20250402083204.1523470-14-suraj.kandpal@intel.com (mailing list archive)
State New
Headers show
Series DPLL framework redesign | expand

Commit Message

Kandpal, Suraj April 2, 2025, 8:32 a.m. UTC
Rename intel_unreference_dpll_global_crtc to intel_dpll_unreference_crtc
in an effort to keep names of exported functions start with the filename.

Signed-off-by: Suraj Kandpal <suraj.kandpal@intel.com>
---
 drivers/gpu/drm/i915/display/intel_dpll_mgr.c      | 10 +++++-----
 drivers/gpu/drm/i915/display/intel_dpll_mgr.h      |  6 +++---
 drivers/gpu/drm/i915/display/intel_modeset_setup.c |  6 +++---
 3 files changed, 11 insertions(+), 11 deletions(-)
diff --git a/drivers/gpu/drm/i915/display/intel_dpll_mgr.h b/drivers/gpu/drm/i915/display/intel_dpll_mgr.h
index bc93cb36b737..f240018416c7 100644
--- a/drivers/gpu/drm/i915/display/intel_dpll_mgr.h
+++ b/drivers/gpu/drm/i915/display/intel_dpll_mgr.h
@@ -404,9 +404,9 @@  int intel_reserve_dpll_globals(struct intel_atomic_state *state,
 			       struct intel_encoder *encoder);
 void intel_release_dpll_globals(struct intel_atomic_state *state,
 				struct intel_crtc *crtc);
-void intel_unreference_dpll_global_crtc(const struct intel_crtc *crtc,
-					const struct intel_dpll_global *pll,
-					struct intel_dpll_state *shared_dpll_state);
+void intel_dpll_unreference_crtc(const struct intel_crtc *crtc,
+				 const struct intel_dpll_global *pll,
+				 struct intel_dpll_state *shared_dpll_state);
 void icl_set_active_port_dpll(struct intel_crtc_state *crtc_state,
 			      enum icl_port_dpll_id port_dpll_id);
 void intel_update_active_dpll(struct intel_atomic_state *state,
diff --git a/drivers/gpu/drm/i915/display/intel_modeset_setup.c b/drivers/gpu/drm/i915/display/intel_modeset_setup.c
index 4221d1566c8a..191027c9bd4f 100644
--- a/drivers/gpu/drm/i915/display/intel_modeset_setup.c
+++ b/drivers/gpu/drm/i915/display/intel_modeset_setup.c
@@ -92,9 +92,9 @@  static void intel_crtc_disable_noatomic_begin(struct intel_crtc *crtc,
 	crtc->base.enabled = false;
 
 	if (crtc_state->dpll_global)
-		intel_unreference_dpll_global_crtc(crtc,
-						   crtc_state->dpll_global,
-						   &crtc_state->dpll_global->state);
+		intel_dpll_unreference_crtc(crtc,
+					    crtc_state->dpll_global,
+					    &crtc_state->dpll_global->state);
 }
 
 static void set_encoder_for_connector(struct intel_connector *connector,
diff mbox series

Patch

diff --git a/drivers/gpu/drm/i915/display/intel_dpll_mgr.c b/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
index 97447ac0fcdf..dd1f2104d5b1 100644
--- a/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
+++ b/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
@@ -455,7 +455,7 @@  intel_reference_dpll_global(struct intel_atomic_state *state,
 }
 
 /**
  * intel_unreference_dpll_global_crtc - Drop a DPLL reference for a CRTC
  * @crtc: CRTC on which behalf the reference is dropped
  * @pll: DPLL for which the reference is dropped
  * @dpll_state: the DPLL atomic state in which the reference is tracked
@@ -463,9 +463,9 @@  intel_reference_dpll_global(struct intel_atomic_state *state,
  * Drop a reference for @pll tracking the end of use of it by @crtc.
  */
 void
-intel_unreference_dpll_global_crtc(const struct intel_crtc *crtc,
-				   const struct intel_dpll_global *pll,
-				   struct intel_dpll_state *dpll_state)
+intel_dpll_unreference_crtc(const struct intel_crtc *crtc,
+			    const struct intel_dpll_global *pll,
+			    struct intel_dpll_state *dpll_state)
 {
 	struct intel_display *display = to_intel_display(crtc);
 
@@ -485,7 +485,7 @@  static void intel_unreference_dpll_global(struct intel_atomic_state *state,
 
 	dpll_state = intel_atomic_get_dpll_global_state(&state->base);
 
-	intel_unreference_dpll_global_crtc(crtc, pll, &dpll_state[pll->index]);
+	intel_dpll_unreference_crtc(crtc, pll, &dpll_state[pll->index]);
 }
 
 static void intel_put_dpll(struct intel_atomic_state *state,
@@ -455,7 +455,7 @@  intel_reference_dpll_global(struct intel_atomic_state *state,
 
 /**
- * intel_unreference_dpll_global_crtc - Drop a DPLL reference for a CRTC
+ * intel_dpll_unreference_crtc - Drop a DPLL reference for a CRTC
  * @crtc: CRTC on which behalf the reference is dropped
  * @pll: DPLL for which the reference is dropped